Index: pkg/dartino_compiler/lib/vm_commands.dart |
diff --git a/pkg/fletchc/lib/vm_commands.dart b/pkg/dartino_compiler/lib/vm_commands.dart |
similarity index 99% |
rename from pkg/fletchc/lib/vm_commands.dart |
rename to pkg/dartino_compiler/lib/vm_commands.dart |
index 355b9ffa7d093feb236982b35f22c34623660b88..28e00be0ebffb7e6c221c9a5c81efb57d6613167 100644 |
--- a/pkg/fletchc/lib/vm_commands.dart |
+++ b/pkg/dartino_compiler/lib/vm_commands.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletchc.vm_commands; |
+library dartino_compiler.vm_commands; |
import 'dart:convert' show |
UTF8; |
@@ -152,7 +152,7 @@ abstract class VmCommand { |
/// If the number is unknown (e.g. one response determines whether more will |
/// come) this will be `null`. |
/// |
/// Some of the [VmCommand]s will instruct the fletch-vm to continue running |
/// the program. The response [VmCommand] can be one of |
/// * ProcessBreakpoint |
/// * ProcessTerminated |
@@ -152,7 +152,7 @@ abstract class VmCommand { |
/// come) this will be `null`. |
/// |
- /// Some of the [VmCommand]s will instruct the fletch-vm to continue running |
+ /// Some of the [VmCommand]s will instruct the dartino-vm to continue running |
/// the program. The response [VmCommand] can be one of |
/// * ProcessBreakpoint |